/* 
PriestleyTaylor.c
calculation potential evaporation using PT-method of DSSAT model

*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*
Biome-BGCMuSo v7.0.
Copyright 2022, D. Hidy [dori.hidy@gmail.com]
Hungarian Academy of Sciences, Hungary
See the website of Biome-BGCMuSo at http://nimbus.elte.hu/bbgc/ for documentation, model executable and example input files.
*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*
*/

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <math.h>
#include <malloc.h>
#include "ini.h"
#include "bgc_struct.h"
#include "bgc_func.h"
#include "bgc_constants.h"
#define MIN(X, Y) (((X) < (Y)) ? (X) : (Y))
#define MAX(X, Y) (((X) > (Y)) ? (X) : (Y))

int PriestlyTaylor(const soilprop_struct* sprop, const epconst_struct* epc, const metvar_struct* metv, epvar_struct *epv, wflux_struct* wf)
{
	int errorCode=0;

	double EEQ, PET;			/* internal variable of DSSAT model */
	double wisp = 3;			/* wind speed (no input data - constans value = 3m/s) */

	if (epc->ET_flag)
	{
		/* unit change: W/m2 to MJ/m2/day */
		EEQ = metv->swavgfd * (nSEC_IN_DAY / 1000000.)  * (4.88E-3 - 4.37E-3*epv->albedo_LAI)*(0.6*metv->Tmax+0.4*metv->Tmin+29);

		PET = 1.1*EEQ*(1+wisp/100);

		if (metv->Tmax > epc->assim_opt2T) PET=EEQ*((metv->Tmax-epc->assim_opt2T)*0.05+1.1);
		if (metv->Tmax < 5)                PET=EEQ*0.01*exp(0.18*(metv->Tmax+20.0));

		if (epv->proj_lai <= 1)
			wf->potEVP = PET*(1-0.43*epv->proj_lai);
		else
			wf->potEVP = MIN(PET, EEQ*exp(-0.4*epv->proj_lai));

		wf->soilwTRP_POT = PET - wf->potEVP;
		wf->canopyw_to_soilw += wf->canopywEVP;
		wf->canopywEVP   = 0;
	}


return(errorCode);
}

