/* 
pondANDrunoffD.c
state update of pond water, calculation of Dunnian runoff 

*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*
Biome-BGCMuSo v7.0.
Copyright 2022, D. Hidy [dori.hidy@gmail.com]
Hungarian Academy of Sciences, Hungary
See the website of Biome-BGCMuSo at http://nimbus.elte.hu/bbgc/ for documentation, model executable and example input files.
*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*
*/


#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <math.h>
#include <malloc.h>
#include "ini.h"
#include "bgc_struct.h"
#include "bgc_constants.h"
#include "bgc_func.h"


int pondANDrunoffD(control_struct* ctrl, siteconst_struct* sitec, soilprop_struct* sprop, epvar_struct* epv, wstate_struct* ws, wflux_struct* wf)
{

	/* internal variables */
	int errorCode, layer, flagEXTRA;

	errorCode=layer=flagEXTRA=0;

	/* water flux from soil to pond */
	ws->pondw += wf->soilw_to_pondw;
	

		
	/* GW-recharge - waterlogging */
	if (ws->GW_waterlogging && ws->pondw < ws->GW_waterlogging)
	{
		wf->GW_to_pondw = ws->GW_waterlogging - ws->pondw;
		ws->pondw       = ws->GW_waterlogging;
	}

	/* Dunnian runoff */
	if (ws->pondw > sprop->pondmax)
	{
		wf->pondw_to_runoff  = ws->pondw - sprop->pondmax;
		ws->pondw            = sprop->pondmax;	
	}
	
	/* pond_flag: flag of WARNING writing (only at first time) */
	if (!ctrl->pond_flag ) ctrl->pond_flag = 1;


	return (errorCode);
}
